unit TabListBoxReg;
{$DEFINE RXComp}
{$DEFINE Actions}

{$WARNINGS OFF}
interface

{$IFDEF Actions}
uses
  ActnList, Classes, StdCtrls;

type
  TListAction = class (TAction)
  public
    function HandlesTarget (Target: TObject): Boolean; override;
    procedure UpdateTarget (Target: TObject); override;
  end;

  TListCutAction = class (TListAction)
  public
    procedure ExecuteTarget(Target: TObject); override;
  end;

  TListCopyAction = class (TListAction)
  public
    procedure ExecuteTarget(Target: TObject); override;
  end;

  TListPasteAction = class (TListAction)
  public
    procedure UpdateTarget (Target: TObject); override;
    procedure ExecuteTarget (Target: TObject); override;
  end;
{$ENDIF}

procedure Register;

implementation
uses {$IFNDEF Actions}Classes,{$ENDIF} DsgnIntf, TabListBox {$IFDEF RXComp}, TabListEditor {$ENDIF}
     {$IFDEF Actions},Windows, Clipbrd{$ENDIF};

procedure Register;
begin
 RegisterComponents('Standard', [TListBoxRk]);
 {$IFDEF RXComp}
 RegisterComponentEditor(TListBoxRk, TListBoxRkEditor);
 {$ENDIF}
 {$IFDEF Actions}
 RegisterActions ('ListBox',
    [TListCutAction, TListCopyAction, TListPasteAction],nil);
 {$ENDIF}
end;

{$IFDEF Actions}
function TListAction.HandlesTarget (Target: TObject): Boolean;
begin
  Result := (Target is TCustomListBox) and
    TCustomListBox(Target).Focused;
end;

procedure TListAction.UpdateTarget(Target: TObject);
begin
  Enabled := ((Target as TCustomListBox).Items.Count > 0) and
    ((Target as TCustomListBox).ItemIndex >= 0);
end;

procedure TListCopyAction.ExecuteTarget(Target: TObject);
begin
  with Target as TCustomListBox do
    Clipboard.AsText := Items [ItemIndex];
end;

procedure TListCutAction.ExecuteTarget(Target: TObject);
begin
  with Target as TCustomListBox do
  begin
    Clipboard.AsText := Items [ItemIndex];
    Items.Delete (ItemIndex);
  end;
end;

type
 TCrackCustomListBox=class(TCustomListBox);

procedure TListPasteAction.ExecuteTarget(Target: TObject);
var
 Lb:TCustomListBox;
begin
 Lb:=Target as TCustomListBox;
 if TCrackCustomListBox(Lb).Sorted then
   Lb.ItemIndex:=Lb.Items.Add(Clipboard.AsText)
 else
 begin
   Lb.Items.Insert(Lb.ItemIndex,Clipboard.AsText);
   if Lb.ItemIndex>0 then Lb.ItemIndex:=Lb.ItemIndex-1;
 end;
end;

procedure TListPasteAction.UpdateTarget(Target: TObject);
begin
  Enabled := Clipboard.HasFormat (CF_TEXT);
end;
{$ENDIF}
end.
